@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 import base64
-import six
 import datetime
-from sqlalchemy.types import TypeDecorator, String, Binary
-from sqlalchemy_utils.exceptions import ImproperlyConfigured
+
+import six
+from sqlalchemy.types import Binary, String, TypeDecorator
+
+from ..exceptions import ImproperlyConfigured
 from .scalar_coercible import ScalarCoercible
 
 cryptography = None
@@ -81,7 +83,7 @@ class AesEngine(EncryptionDecryptionBaseEngine):
             value = str(value)
         decryptor = self.cipher.decryptor()
         decrypted = base64.b64decode(value)
-        decrypted = decryptor.update(decrypted)+decryptor.finalize()
+        decrypted = decryptor.update(decrypted) + decryptor.finalize()
         decrypted = decrypted.rstrip(self.PADDING)
         if not isinstance(decrypted, six.string_types):
             decrypted = decrypted.decode('utf-8')
