@@ -1,15 +1,17 @@
-import six
 import weakref
-from sqlalchemy_utils.exceptions import ImproperlyConfigured
+
+import six
 from sqlalchemy import types
-from sqlalchemy.dialects import postgresql, oracle
-from .scalar_coercible import ScalarCoercible
+from sqlalchemy.dialects import oracle, postgresql
 from sqlalchemy.ext.mutable import Mutable
 
+from ..exceptions import ImproperlyConfigured
+from .scalar_coercible import ScalarCoercible
+
 passlib = None
 try:
     import passlib
-    from passlib.context import CryptContext
+    from passlib.context import LazyCryptContext
 except ImportError:
     pass
 
@@ -80,7 +82,9 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
     verifying them using a pythonic interface.
 
     All keyword arguments (aside from max_length) are forwarded to the
-    construction of a `passlib.context.CryptContext` object.
+    construction of a `passlib.context.LazyCryptContext` object, which
+    also supports deferred configuration via the `onload` callback.
+
 
     The following usage will create a password column that will
     automatically hash new passwords as `pbkdf2_sha512` but still compare
@@ -113,6 +117,29 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
         target.password == 'b'
         # True
 
+
+    Lazy configuration of the type with Flask config:
+
+    ::
+
+
+        import flask
+
+        class User(db.Model):
+            __tablename__ = 'user'
+
+            password = db.Column(
+                PasswordType(
+                    # The returned dictionary is forwarded to the CryptContext
+                    onload=lambda **kwargs: dict(
+                        schemes=flask.current_app.config['PASSWORD_SCHEMES'],
+                        **kwargs
+                    ),
+                ),
+                unique=False,
+                nullable=False,
+            )
+
     """
 
     impl = types.VARBINARY(1024)
@@ -126,13 +153,17 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
             )
 
         # Construct the passlib crypt context.
-        self.context = CryptContext(**kwargs)
+        self.context = LazyCryptContext(**kwargs)
 
-        if max_length is None:
-            max_length = self.calculate_max_length()
+        self._max_length = max_length
 
-        # Set the length to the now-calculated max length.
-        self.length = max_length
+    @property
+    def length(self):
+        """Get column length."""
+        if self._max_length is None:
+            self._max_length = self.calculate_max_length()
+
+        return self._max_length
 
     def calculate_max_length(self):
         # Calculate the largest possible encoded password.
@@ -205,5 +236,9 @@ class PasswordType(types.TypeDecorator, ScalarCoercible):
 
         return value
 
+    @property
+    def python_type(self):
+        return self.impl.type.python_type
+
 
 Password.associate_with(PasswordType)
